<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

class Happiness_Reports_For_Help_Scout_Admin {

	public function __construct() {
		add_action( 'admin_menu', array( $this, 'register_menu' ) );
		add_action( 'admin_init', array( $this, 'settings' ) );
		add_action( 'update_option_help_scout_happiness_reports', array( $this, 'delete_transient' ), 10, 2 );
		add_action( 'wp_ajax_validate_helpscout_app_keys', array( $this, 'validate_helpscout_app_keys' ) );
		self::create_auth();
	}

	/**
	 * Delete transient when the admin settings are saved
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function delete_transient( $old_value, $new_value ) {
		delete_transient( 'happiness_reports_ratings' );
	}

	public function create_auth()
	{		 
		if(isset($_REQUEST['code']) && $_REQUEST['code'] != '')
		{
			$code = $_REQUEST['code'];

			$options = get_option( 'help_scout_happiness_reports' );
			
			$app_secret = $options['help_scout_app_secret'];
			$app_id = $options['help_scout_app_id'];
			
			$body = array(
            					'code' => $code,
            					'client_id' => $app_id,
            					'client_secret' => $app_secret,
            					'grant_type' => 'authorization_code'
            				);
						
			$body = json_encode($body);
			$url = 'https://api.helpscout.net/v2/oauth2/token';
			$ch = curl_init();
		    curl_setopt($ch, CURLOPT_URL, $url);
		    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
		    curl_setopt($ch, CURLOPT_POSTFIELDS, $body );
		    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);  
		    curl_setopt($ch, CURLOPT_HTTPHEADER, array(                                                                          
		      'Content-Type: application/json'                                                                     
		    ));               
		  	
		    $result = curl_exec($ch);	
		  	if(!curl_errno($ch)) {	
		  	  update_option('helpscout_auth_token', $result);
		  	}
		  	curl_close($ch);
		  	?>
		  	<script type="text/javascript">
		  		var url = '<?php echo admin_url('options-general.php?page=satisfaction-reports-from-help-scout'); ?>';		  		
		  		window.location = url;
		  	</script>		  	
		  	<?php
		}
	}

	/**
	 * Register menu
	 *
	 * @since 1.0.0
	 */
	public function register_menu() {

		add_options_page(
			__( 'Satisfaction Reports', 'satisfaction-reports-from-help-scout' ),
			__( 'Satisfaction Reports', 'satisfaction-reports-from-help-scout' ),
			'manage_options',
			'satisfaction-reports-from-help-scout',
			array( $this, 'admin_page' )
		);

	}

	/**
	 * Admin page
	 *
	 * @since 1.0.0
	 */
	public function admin_page() { 
	$url = admin_url('options-general.php?page=satisfaction-reports-from-help-scout');
	$path = plugin_dir_url(__FILE__); 
	?>
	<style type="text/css">
		.wrap{
			overflow: hidden;
		}
		.happiness_leftbar
		{
			float: left;
			width: 70%;
			padding-right: 10px;
		}
		.happiness-right_sidebar{
			float: right;
			width: 29%;
		}
		.happiness_rightbar, .happiness_rightbar_bottom
		{
			width: 100%;
		}
		.happiness_rightbar{
			padding-top: 3%;
		}
		.happiness_rightbar_bottom{
			padding-top: 4%;
		}
		.happiness_rating, .happiness_rating_display{			
			height: auto;
			border: 1px solid #d3d3d3;
			background: #ffffff;
		}
		.happiness_rating, .reports_content{
			padding: 15px 18px;	
		}
		.happiness_rating .starfish_reviews{
			font-size: 20px;
			text-align: center;
			font-weight: 600;
			line-height: 1.2;
		}
		.happiness_rating .starfish_socials{
			font-size: 17px;
			text-align: center;
			font-weight: 600;
		}
		.happiness_rating .starfish_products_check{
			font-size: 16px;
			text-align: center;
			font-weight: 500;
			letter-spacing: 0.03em;
		}
		.rating_img, .reviews_img{			
			/*width: 400px;*/
			/*padding: 10px;*/
		}
		.rating_img img, .reviews_img img{
			width: 100%;
		}
		.reports_content{
			padding-top :5px;
		}
		.reports_content p{
			font-size: 15px;
			font-weight: 600;
			margin-top: 6px;
			margin-bottom: 6px;
			letter-spacing: 0.02em;
		}
		.happiness_display_report{
			padding: 2px 15px;
			margin-top:2px;
			margin-bottom: 2px;
			font-size: 18px;
			font-weight: 600;
			letter-spacing: 0.02em;
		}
		.happiness-plugin_reviews{
			padding: 15px 0;
		}
		.reviews_img a{
			outline: none !important;
			display: block;
		}
		@media only screen and (max-width: 1507px) {
			 span.happiness_auth_label{
				width: 100%;
				display: block;
				padding-bottom: 7px;
			}
			span.happiness_auth_url{
				display: block;
			}
		}
		@media only screen and (max-width: 1200px) {
			.happiness_leftbar{
				width: 100%;
			}
			.happiness-right_sidebar{
				width: 100%;
				float: left;
				overflow: hidden;
			}
			.happiness_rightbar, .happiness_rightbar_bottom{
				width: 47%;
				
			}
			.happiness_rightbar{
				float: left;
			}
			.happiness_rightbar_bottom{
				float: right;
			}
		}


	</style>
	   <div class="wrap">
	    	<div class="happiness_leftbar">
	    	 <?php screen_icon( 'plugins' ); ?>
	        <h2><?php _e( 'Satisfaction Reports from Help Scout', 'satisfaction-reports-from-help-scout' ); ?></h2>
	        <p><?php _e( '<span class="happiness_auth_label" font-weight: bold;">Set OAuth redirect URL in Help Scout: </span><span class="happiness_auth_url" style="background:#e2e2e2; padding:8px;  -webkit-user-select: all; user-select: all;">'.$url.'</span>', 'satisfaction-reports-from-help-scout' ); ?></p>
	        <form action="options.php" method="POST">
	            <?php
		            settings_fields( 'satisfaction-reports-from-help-scout' );
		            do_settings_sections( 'satisfaction-reports-from-help-scout' );
	            ?>

	            <?php submit_button(); ?>
	        </form>
	        </div>
	        <div class="happiness-right_sidebar">
		        <div class="happiness_rightbar">
		        	<div class="happiness_rating">
		        		<div class="rating_img"><img src="<?php echo $path.'images/rating-star-increase-reviews-animation-wide.svg'; ?>"></div>
		        		<span><p class="starfish_reviews">Want to Generate More Reviews On Other Platforms?</p></span>
		        		<span><p class="starfish_socials">(Google, TrustPilot, Facebook & more)</p></span>
		        		<span><p class="starfish_products_check">Check Out Our Other Plugin!</p></span>
		        		<div class="reviews_img">
		        			<a target="_blamk" style="transition-property:unset !important;" href="https://starfish.reviews/?utm_source=sat_reports_hs_plugin&utm_medium=plugin_settings_wp_admin&utm_campaign=plugins">
		        				<img src="<?php echo $path.'images/starfish-reviews-logo-final.png'; ?>" >
		        			</a> 
		        		</div>
		        	</div>
		        </div>
		         <div class="happiness_rightbar_bottom">
		        	<div class="happiness_rating_display">
		        		<span><p class="happiness_display_report">How to Display Satisfaction Reports</p></span>
		        		<hr>
		        		<div class="reports_content">
		        			<span>
		        			<p>1. <a target="_blank" href="https://wordpress.org/plugins/happiness-reports-for-help-scout/#faq-header">Connect to Help Scout.</a></p>
							<p>2. Select mailbox(es) and date range.</p>
							<p>3. <a target="_blank" href="https://wordpress.org/plugins/happiness-reports-for-help-scout/#faq-header">Use (shortocdes or PHP)</a> to display.</p>
							</span>
							<div class="happiness-plugin_reviews">
								<p>★ ★ ★ ★ ★</p>
								<p>Like this plugin? Please <a target="_blank" href="https://wordpress.org/support/plugin/happiness-reports-for-help-scout/reviews/#new-post">review on WP.org!</a></p>
							</div>
		        		</div>
		        	</div>
		        </div>
		    </div>
	    </div>
	<?php }

	/**
	 * Default values
	 *
	 * @since  1.0.0
	 */
	public function default_options() {

		$defaults = array(
			'help_scout_api_key'    => '',
			'help_scout_date_range' => 'last_12_months'
		);

		return apply_filters( 'hrfhs_default_options', $defaults );

	}

	/**
	 * Settings
	 *
	 * @since  1.0.0
	 */
	public function settings() {

		if ( false == get_option( 'help_scout_happiness_reports' ) ) {
			add_option( 'help_scout_happiness_reports', $this->default_options() );
		}

		add_settings_section(
			'happiness-reports',
			'',
			'',
			'satisfaction-reports-from-help-scout'
		);

		/*add_settings_field(
			'help_scout_api_key',
			__( 'Help Scout API Key', 'satisfaction-reports-from-help-scout' ),
			array( $this, 'callback_input' ),
			'satisfaction-reports-from-help-scout',
			'happiness-reports',
			array(
				'name'        => 'help_scout_api_key',
				'id'          => 'help-scout-api-key',
				'description' => __( 'Enter your Help Scout API Key', 'satisfaction-reports-from-help-scout' )
			)
		);*/

		add_settings_field(
			'help_scout_app_id',
			__( 'Help Scout App Id', 'satisfaction-reports-from-help-scout' ),
			array( $this, 'callback_input' ),
			'satisfaction-reports-from-help-scout',
			'happiness-reports',
			array(
				'name'        => 'help_scout_app_id',
				'id'          => 'help-scout-app-id',
				'description' => __( 'Enter your Help Scout App ID', 'satisfaction-reports-from-help-scout' )
			)
		);

		add_settings_field(
			'help_scout_app_secret',
			__( 'Help Scout App Secret', 'satisfaction-reports-from-help-scout' ),
			array( $this, 'callback_input_pass' ),
			'satisfaction-reports-from-help-scout',
			'happiness-reports',
			array(
				'name'        => 'help_scout_app_secret',
				'id'          => 'help-scout-app-secret',
				'description' => __( 'Enter your Help Scout App Secret', 'satisfaction-reports-from-help-scout' )
			)
		);

		add_settings_field(
			'help_scout_auth',
			'',
			//__( 'Help Scout Mailbox', 'satisfaction-reports-from-help-scout-auth' ),
			array( $this, 'callback_mailboxes_auth' ),
			'satisfaction-reports-from-help-scout',
			'happiness-reports',
			'help_scout_mailboxes-auth'
		);

		$token = json_decode(get_option('helpscout_auth_token'));

		if(isset($token->access_token) && $token->access_token != '' )
		{
			add_settings_field(
				'help_scout_mailboxes',
				__( 'Help Scout Mailbox', 'satisfaction-reports-from-help-scout' ),
				array( $this, 'callback_mailboxes' ),
				'satisfaction-reports-from-help-scout',
				'happiness-reports',
				array(
					'name'        => 'help_scout_mailboxes',
					'id'          => 'help-scout-mailboxes',
					'description' => __( 'Select the mailbox', 'satisfaction-reports-from-help-scout' )
				)
			);

			add_settings_field(
				'help_scout_date_range',
				__( 'Date Range', 'satisfaction-reports-from-help-scout' ),
				array( $this, 'callback_date_range' ),
				'satisfaction-reports-from-help-scout',
				'happiness-reports',
				array(
					'name'        => 'help_scout_date_range',
					'id'          => 'help-scout-date-range',
					'description' => __( 'Select a date range', 'satisfaction-reports-from-help-scout' ),
					'options'     => array(
						'last_7_days'    => 'Last 7 Days',
						'this_month'     => 'This Month',
						'last_month'     => 'Last Month',
						'last_6_months'  => 'Last 6 Months',
						'last_12_months' => 'Last 12 Months'
					)
				)
			);	
		}

		register_setting(
			'satisfaction-reports-from-help-scout',
			'help_scout_happiness_reports',
			array( $this, 'sanitize' )
		);

	}

	public function validate_helpscout_app_keys() {
		$app_id = isset($_REQUEST['app_id']) ? $_REQUEST['app_id'] : '';
		$app_secret = isset($_REQUEST['app_secret']) ? $_REQUEST['app_secret'] : '';
		$request_url = 'https://api.helpscout.net/v2/oauth2/token';

		$options = get_option( 'help_scout_happiness_reports' );
		$options['help_scout_app_id'] = $app_id;
		$options['help_scout_app_secret'] = $app_secret;

		update_option('help_scout_happiness_reports', $options);

		$body = array(
						'grant_type' => 'client_credentials',
						'client_id' => $app_id,
						'client_secret' => $app_secret
					);

		$request_args = array(
			'body'      => json_encode( $body ),
			'method'    => 'POST',
			'sslverify' => false,
			'headers'   => array(
				'Accept'       => 'application/json',
				'Content-Type' => 'application/json',
			),
		);

		//$request_args['headers']['Authorization'] = 'Bearer ' . $this->get_access_token( 'access_token' );

		$response = wp_remote_request( $request_url, $request_args );

		if( is_wp_error( $response ) ) {			
			return false;
			exit;
		}

		echo $response['response']['code'];
		exit;
	}


	public function callback_mailboxes_auth()
	{
		$options = get_option( 'help_scout_happiness_reports' );
		$token = json_decode(get_option('helpscout_auth_token'));

		$connected = '';
		$flag = 'false';
		$path = plugin_dir_url(__FILE__); 
		$image_path = $path.'images/loading.gif';
		$connected_img = $path.'images/right.png';

		if(isset($token->access_token) && $token->access_token != '' )
		{
			$flag = 'true';
			$connected = '<span style="padding-left:15px; "><img src="'.$connected_img.'" height="24" width="24" ></span>';

		}
        
        $app_secret = isset($options['help_scout_app_secret']) ? $options['help_scout_app_secret'] : '';
        $app_id = isset($options['help_scout_app_id']) ? $options['help_scout_app_id'] : '';

		if($app_secret != '' && $app_id != '')		
		{
			?>
			<script type="text/javascript">					
				jQuery(document).ready(function(){
				  
				  validate_helpscout_auth();
				  
				  jQuery("#help-scout-app-id, #help-scout-app-secret").on('keyup keypress select', function(){
				  	validate_helpscout_auth();
				  });
				  
				});

				function validate_helpscout_auth()
				{
					jQuery('.auth_loading').css('display', '');
				  	var app_id = jQuery("#help-scout-app-id").val();
				    var app_secret = jQuery("#help-scout-app-secret").val();
				  
				  	var data = {
			  				'action': 'validate_helpscout_app_keys',
			  				'app_id' : app_id,
			  				'app_secret' : app_secret
			  			};

		  			jQuery.post(ajaxurl, data, function(response) {
		  				if(response == 200)
		  				{
		  					jQuery('.authorize_link').css({'pointer-events':'', 'cursor':'', 'opacity':''});
		  					jQuery('.auth_loading').css('display', 'none');
		  					//jQuery('#submit').show();
		  				} else{
		  					jQuery('.authorize_link').css({'pointer-events':'none', 'cursor':'not-allowed', 'opacity':'0.5'});
		  					jQuery('.auth_loading').css('display', 'none');
		  					//jQuery('#submit').hide();		  					
		  				}
		  			});

				    var url='https://secure.helpscout.net/authentication/authorizeClientApplication?client_id='+app_id+'&state='+app_secret;

				    jQuery(".authorize_link").attr("href", url);
				}

			</script>
			<?php
						
			if($flag == 'true')
			{
				echo '<a class="button button-primary authorize_link" href="https://secure.helpscout.net/authentication/authorizeClientApplication?client_id='.$app_id.'&state='.$app_secret.'" >Click here to re-authenticate with Help Scout</a><span><img class="auth_loading" style="display:none; padding-left: 10px;" src="'.$image_path.'"></img</span>'.$connected;
			} else {
				echo '<a class="button button-primary authorize_link" href="https://secure.helpscout.net/authentication/authorizeClientApplication?client_id='.$app_id.'&state='.$app_secret.'" >Click here to authenticate with Help Scout</a><span><img class="auth_loading" style="display:none; padding-left: 10px;" src="'.$image_path.'"></img</span>'.$connected;
			}
		}
	}
	
	
	/**
	 * Input field callback
	 *
	 * @since  1.0.0
	 */
	public function callback_input( $args ) {

		$options = get_option( 'help_scout_happiness_reports' );
		$value   = isset( $options[$args['name']] ) ? $options[$args['name']] : '';
	?>
		<input type="text" class="regular-text" id="<?php echo $args['id']; ?>" name="help_scout_happiness_reports[<?php echo $args['name']; ?>]" value="<?php echo $value; ?>" required />

		<?php if ( isset( $args['description'] ) ) : ?>
			<p class="description"><?php echo $args['description']; ?></p>
		<?php endif; ?>
		<?php

	}

	public function callback_input_pass( $args ) {

		$options = get_option( 'help_scout_happiness_reports' );
		$value   = isset( $options[$args['name']] ) ? $options[$args['name']] : '';
	?>
		<input type="password" class="regular-text" id="<?php echo $args['id']; ?>" name="help_scout_happiness_reports[<?php echo $args['name']; ?>]" value="<?php echo $value; ?>" required />

		<?php if ( isset( $args['description'] ) ) : ?>
			<p class="description"><?php echo $args['description']; ?></p>
		<?php endif; ?>
		<?php

	}


	/**
	 * Date range callback
	 *
	 * @since  1.0.0
	 */
	public function callback_date_range( $args ) {

		$options = get_option( 'help_scout_happiness_reports' );
		$value   = isset( $options[$args['name']] ) ? $options[$args['name']] : '';

	?>

		<select id="<?php echo $args['id']; ?>" name="help_scout_happiness_reports[<?php echo $args['name']; ?>]">
			<?php foreach( $args['options'] as $date_range => $label ) : ?>
			<option value="<?php echo $date_range; ?>" <?php selected( $value, $date_range ); ?>><?php echo $label; ?></option>
			<?php endforeach; ?>
		</select>

		<?php if ( isset( $args['description'] ) ) : ?>
			<p class="description"><?php echo $args['description']; ?></p>
		<?php endif; ?>
		<?php

	}

	/**
	 * Mailboxes callback
	 *
	 * @since  1.0.0
	 */
	public function callback_mailboxes( $args ) {
	

		$options   = get_option( 'help_scout_happiness_reports' );

		$mailboxes = happiness_reports_for_help_scout()->functions->get_mailboxes();


        // get API key
        $api_key = $options['help_scout_app_secret'];

		if ( ! $api_key ) {
			_e( 'Please enter you App Id and App Secret above and click "Save Changes" to view your mailboxes', 'satisfaction-reports-from-help-scout' );
		}

		if ( empty( $mailboxes ) ) {
			return;
		}

		foreach ( $mailboxes as $key => $mailbox ) :

		$checked = isset( $options['help_scout_mailboxes'][$key] ) ? $options['help_scout_mailboxes'][$key] : '';
	?>

		<label for="<?php echo $mailbox->id; ?>" class="description">
			<input type="checkbox" class="" id="<?php echo $mailbox->id; ?>" name="help_scout_happiness_reports[<?php echo $args['name']; ?>][<?php echo $key; ?>]" value="<?php echo $mailbox->id; ?>"  <?php checked( $checked, $mailbox->id ); ?> />
			<?php echo $mailbox->name; ?>
		</label>
		<br />

	<?php endforeach; ?>
		<?php

	}

	/**
	 * Sanitization callback
	 *
	 * @since  1.0.0
	 */
	public function sanitize( $input ) {

		// Create our array for storing the validated options
		$output = array();

		// Loop through each of the incoming options
		foreach ( $input as $key => $value ) {

			// Check to see if the current option has a value. If so, process it.
			if ( isset( $input[$key] ) ) {
				$output[$key] = $input[ $key ];
			}

		}

		// Return the array processing any additional functions filtered by this action
		return apply_filters( 'hrfhs_sanitize', $output, $input );

	}


}

$help_scout_happiness_reports_admin = new Happiness_Reports_For_Help_Scout_Admin;
